@@ -1,23 +1,23 @@
-test_that("FSelectorDesignPoints", {
+test_that("default parameters work", {
   design = data.table(
     x1 = c(TRUE, FALSE),
     x2 = c(TRUE, FALSE),
     x3 = c(FALSE, TRUE),
     x4 = c(FALSE, TRUE))
 
-  z = test_fselector("design_points", design = design, batch_size = 10, term_evals = 10, real_evals = 2)
+  z = test_fselector("design_points", design = design)
   a = z$inst$archive$data
   expect_equal(a[, 1:4], design)
 })
 
-test_that("FSelectorDesignPoints works with multi-crit", {
+test_that("multi-crit works", {
   design = data.table(
     x1 = c(TRUE, FALSE),
     x2 = c(TRUE, FALSE),
     x3 = c(FALSE, TRUE),
     x4 = c(FALSE, TRUE))
 
-  z = test_fselector_2D("design_points", design = design, batch_size = 1, term_evals = 10, real_evals = 2)
+  z = test_fselector_2D("design_points", design = design)
   a = z$inst$archive$data
   expect_equal(a[, 1:4], design)
 })
